@@ -1,5 +1,5 @@
 /* GADMIN-SQUID - An easy to use GTK+ frontend for the Squid proxy server.
- * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -133,8 +133,8 @@ void create_main_window(struct w *widgets)
                              G_CALLBACK(show_help), widgets);
 
 
-    /* About/Credits button */
-    GtkWidget *toolbar_icon_about = gtk_image_new_from_stock("gtk-justify-center", 
+    /* About button */
+    GtkWidget *toolbar_icon_about = gtk_image_new_from_stock("gtk-about", 
                                       gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *about_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
