@@ -1,5 +1,5 @@
 /* GADMIN-SQUID - An easy to use GTK+ frontend for the Squid proxy server.
- * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -442,8 +442,11 @@ void add_standard_conf(struct w *widgets)
 
     g_free(conf);
 
-    if( GTK_IS_WINDOW(widgets->default_conf_question_window) )
-      gtk_widget_destroy(widgets->default_conf_question_window);
+    if( widgets->default_conf_question_window != NULL )
+    {
+        gtk_widget_destroy(widgets->default_conf_question_window);
+        widgets->default_conf_question_window = NULL;
+    }
 
     populate_gadmin_squid(widgets);
 
@@ -456,7 +459,11 @@ void add_standard_conf(struct w *widgets)
 /* This should probably also write a ~"dont_ask_again=1" to the settings file */
 void dont_add_standard_conf(struct w *widgets)
 {
-    gtk_widget_destroy(widgets->default_conf_question_window);
+    if( widgets->default_conf_question_window != NULL )
+    {
+        gtk_widget_destroy(widgets->default_conf_question_window);
+        widgets->default_conf_question_window = NULL;
+    }
     populate_gadmin_squid(widgets);
 }
 
